# connect

Le bouton FranceConnect est un bouton spécifique permettant d'interagir avec l'API FranceConnect.
https://franceconnect.gouv.fr/


## Dépendances
```shell
connect
└─ core
```

## Utilisation
Afin d’utiliser le composant `connect`, il est nécessaire d’ajouter les fichiers de styles et de scripts présents dans le dossier dist dans l'ordre suivant :\n
```html
<html>
  <head>
    <link href="css/core/core.min.css" rel="stylesheet">
    <link href="css/connect/connect.min.css" rel="stylesheet">
  </head>
  <body>
  </body>
</html>
```

## Documentation

Consulter [la documentation](https://www.systeme-de-design.gouv.fr/elements-d-interface/composants/bouton-franceconnect) sur le module Bouton FranceConnect